rm(list = ls())
library(RColorBrewer)
library(deSolve)
library(extrafont)

#(for numerical solution via deSolve) logistic model for neuston with a basic plastic model and cleanup: based on plasticVelella in teachout/plastic.R, but note changed sign of a3: negative a3 now means negative effect
#Arguments:
#t is time
#state is (x, y): neuston and plastic
#parms: parameters:
#a1 is proportional population growth rate of neuston when rare
#a2 is effect of a unit of neuston on proportional population growth rate (negative sign means negative effect)
#a3 is effect of a unit of plastic on proportional population growth rate of neuston (negative sign means negative effect)
#b1 is plastic input rate
#b2 is plastic loss rate
#c1 is cleanup efficiency of neuston
#c2 is cleanup efficiency of plastic
#k is cleanup effort
#Value: rates of change dx / dt, dy / dt
plasticneustonlogistic <- function(t, state, parms){
    with(as.list(c(state, parms)),{
        dx <- a1 * x + a2 * x^2 + a3 * x * y - c1 * k * x
        dy <- b1 - b2 * y - c2 * k * y
        list(c(dx, dy))
    })

}

#(for numerical solution via deSolve) nondimensionalized logistic model for neuston with a basic plastic model and cleanup
#Arguments:
#t is nondimensionalized time (times plastic natural loss rate)
#state is (xstar, ystar): neuston and plastic nondimensionalized (as fractions of equilibrium values in absence of cleanup)
#parms: Pi1 to Pi4 from getdimensionlessparameters()
#Value: rates of change dxstar / dt, dystar / dt
plasticneustonlogisticnondim <- function(t, state, parms){
    with(as.list(c(state, parms)),{
        dxstar <- xstar * (Pi2 + Pi3 * xstar + Pi4 * ystar)
        dystar <- 1 - Pi1 * ystar
        list(c(dxstar, dystar))
    })
}

#get the cleanup effort k needed to reduce equilibrium plastic to fraction 1/r of equilibrium in absence of cleanup
#Arguments:
#r: 1/r is fraction to which we want to reduce plastic
#b2: natural plastic loss rate
#c2: cleanup efficiency of plastic per unit effort
#Value: required cleanup effort k
getk <- function(r, b2, c2){
    k <- (r - 1) * b2 / c2
    return(k)
}

#find the smallest fraction 1/r to which we can reduce equilibrium plastic without having a negative effect on neuston under the class of Kolmogorov models we are considering
#Arguments:
#a3 is effect of a unit of plastic on proportional population growth rate of neuston (negative sign means negative effect)
#b1 is plastic input rate
#b2 is plastic loss rate
#c1 is cleanup efficiency of neuston
#c2 is cleanup efficiency of plastic
getminfraction <- function(a3, b1, b2, c1, c2){
    minfraction <- -c1 / c2 * b2^2 / (a3 * b1)
    return(minfraction)
}

#get parameters for a nondimensionalized system (logistic neuston, simple plastic) in which x* is neuston / equilibrium in absence of cleanup, y* is plastic / equilibrium in absence of cleanup, t* is time / plastic natural loss rate
#Arguments:
#a1 is proportional population growth rate of neuston when rare
#a3 is effect of a unit of plastic on proportional population growth rate of neuston (negative sign means negative effect)
#b1 is plastic input rate
#b2 is plastic loss rate
#c1 is cleanup efficiency of neuston
#c2 is cleanup efficiency of plastic
#k is cleanup effort
#Value: list containing dimensionless parameters Pi1, Pi2, Pi3, Pi4
getdimensionlessparameters <- function(a1, a3, b1, b2, c1, c2, k){
    Pi1 <- 1 + c2 * k / b2
    Pi2 <- (a1 - c1 * k) / b2
    Pi3 <- (-a1 * b2 - a3 * b1) / b2^2
    Pi4 <- a3 * b1 / b2^2
    return(c(Pi1 = Pi1, Pi2 = Pi2, Pi3 = Pi3, Pi4 = Pi4))
}

#nondimensionalize state for system with logistic neuston, simple plastic
#Arguments:
#x, y are neuston and plastic
#a1 is proportional population growth rate of neuston when rare
#a2 is effect of a unit of neuston on proportional population growth rate (negative sign means negative effect)
#a3 is effect of a unit of plastic on proportional population growth rate of neuston (negative sign means negative effect)
#b1 is plastic input rate
#b2 is plastic loss rate
#Value:
#(xstar, ystar): ratios of neuston and plastic to equilibrium in absence of cleanup
getdimensionlessstate <- function(x, y, a1, a2, a3, b1, b2){
    ytilde <- b1 / b2
    xtilde  <-  (-a1 - a3 * ytilde) / a2
    xstar <- x / xtilde
    ystar  <- y / ytilde
    if(length(x) == 1){#need this format for deSolve
        return(c(xstar = xstar, ystar = ystar))
    } else {
        return(cbind(xstar = xstar, ystar = ystar))
    }
}

#nondimensionalize time for system with logistic neuston, simple plastic
#Arguments: t is time, b2 is natural plastic loss rate
#Value: tstar is t * b2
getdimensionlesstime <- function(t, b2){
    tstar <- t * b2
    return(tstar)
}

#check that nondimensionalization is correct, by comparing nondimensionalized output from original system with output from nondimensionalized system
#Arguments:
#plastic is output from ode (time, neuston, plastic as columns) for dimensional system
#plasticnondim is output from ode for corresponding nondimensionalized system
#a1 is proportional population growth rate of neuston when rare
#a2 is effect of a unit of neuston on proportional population growth rate (negative sign means negative effect)
#a3 is effect of a unit of plastic on proportional population growth rate of neuston (negative sign means negative effect)
#b1 is plastic input rate
#b2 is plastic loss rate
#Value: plots of dimensionless neuston and plastic against time, for the two systems
nondimvsdim <- function(plastic, plasticnondim, a1, a2, a3, b1, b2){
    pnd <- getdimensionlessstate(x = plastic[, 2], y = plastic[, 3], a1 = a1, a2 = a2, a3 = a3, b1 = b1, b2 = b2)
    tnd <- getdimensionlesstime(t = plastic[, 1], b2 = b2)
    par(mfrow = c(2, 1))
    plot(plasticnondim[, 1], plasticnondim[, 2], type = "l", xlab = "dimemsionelss time", ylab = "dimensionless neuston")
    points(tnd, pnd[, 1], col = "red")
    legend("bottomright", pch = c(NA, 1), col = c("black", "red"), lty = c("solid", NA), legend = c("nondimensionalized", "dimensional, converted")) 
    plot(plasticnondim[, 1], plasticnondim[, 3], type = "l", xlab = "dimensionless time", ylab = "dimensionless plastic")
    points(tnd, pnd[, 2], col = "red")
}

#plot equilibrium nondimensionalized neuston against equilibrium nondimensionalized plastic for a range of cleanup effort
#Arguments:
#fname is name of file to plot to as pdf
#a1 is proportional population growth rate of neuston when rare
#a3 is effect of a unit of plastic on proportional population growth rate of neuston (negative sign means negative effect)
#b1 is plastic input rate
#b2 is plastic loss rate
#c1 is cleanup efficiency of neuston
#c2 is cleanup efficiency of plastic
#numerical: check by numerical solution (default FALSE)?
#Value: plot of xstar against ystar. 
ploteffectsizes <- function(fname, a1, a3, b1, b2, c1, c2, numerical = FALSE){
    kset <- seq(from = 0, to = 1, length.out = 1001)
    xstar <- numeric(length(kset))
    ystar <- numeric(length(kset))
    for(i in 1:length(kset)){
        k <- kset[i]
        nondimparms <- getdimensionlessparameters(a1 = a1, a3 = a3, b1 = b1, b2 = b2, c1 = c1, c2 = c2, k = k)
        ystar[i] <- 1 / nondimparms[1]
        xstar[i] <- max(0, (-nondimparms[2] - nondimparms[4] * ystar[i]) / nondimparms[3])
    }
    pdf(file = fname, width = 7, height = 7)
    par(mfrow = c(1, 1))
    par(mar = c(5, 5, 2, 2))
    mycolors <- brewer.pal(3, 'Dark2')
    plot(ystar, xstar, type = "l", xlab = expression(italic(y)^"*"), ylab = expression(italic(x)^"*"), cex.lab = 1.5, lwd = 2, col = mycolors[3])
    points(c(1, 1), pch = 16, col = mycolors[1])
    text(c(1, 1), "no cleanup", adj = c(1, 1.2))
    if(numerical == TRUE){
        for(i in 1:length(kset)){
            k <- kset[i]
            a2 <- -1 #any value is OK here: does not affect outcome
            parameters <- c(a1 = a1, a2 = a2, a3 = a3, c1 = c1, k = k, c2 = c2, b1 = b1, b2 = b2)
            state <- c(x = 0.01, y = 0.1)
            times <- c(0, 1e3)
            nsol <- ode(y = state, times = times, func = plasticneustonlogistic, parms = parameters)
            pnd <- getdimensionlessstate(x = nsol[, 2], y = nsol[, 3], a1 = a1, a2 = a2, a3 = a3, b1 = b1, b2 = b2)
            points(pnd[length(times), 2], pnd[length(times), 1], col = "red")
        }
    }
    minfraction <- getminfraction(a3 = a3, b1 = b1, b2 = b2, c1 = c1, c2 = c2)
    abline(v = minfraction, lty = "dashed")
    abline(h = 1, lty = "dashed")
    points(minfraction, 1, pch = 16, col = mycolors[3])
    text(minfraction, 1, "no net effect", adj = c(-0.2, 1.2))


    kextinct <- getkextinct(a1 = a1, a3 = a3, b1 = b1, b2 = b2, c1 = c1, c2 = c2) #where does extinction happen?
    if(kextinct$k1 > 0){
        ystar0 <- b2 / (b2 + c2 * kextinct$k1)
        y0 <- b1 / (b2 + c2 * kextinct$k1)
        xstar0 <-  (c1 * kextinct$k1 - a1 - a3 * y0) / (-a1 - a3 * b1 / b2)
        points(ystar0, xstar0, col = mycolors[2], pch = 16)
        text(ystar0, xstar0, "extinction", pos = 4)
    }
    if(kextinct$k2 > 0){
        ystar0 <- b2 / (b2 + c2 * kextinct$k2)
        y0 <- b1 / (b2 + c2 * kextinct$k2)
        xstar0 <-  (c1 * kextinct$k2 - a1 - a3 * y0) / (-a1 - a3 * b1 / b2)
        points(ystar0, xstar0, col = mycolors[1], pch = 16)
        text(ystar0, xstar0, "extinction", pos = 4)
    }

    dev.off()
}

#find value of cleanup effort at which neuston go extinct
#Arguments:
#a1 is proportional population growth rate of neuston when rare
#a3 is effect of a unit of plastic on proportional population growth rate of neuston (negative sign means negative effect)
#b1 is plastic input rate
#b2 is plastic loss rate
#c1 is cleanup efficiency of neuston
#c2 is cleanup efficiency of plastic
#Value: list containing k1, k2, the two solutions of a quadratic equation for the value of k at which neuston go extinct
getkextinct <- function(a1, a3, b1, b2, c1, c2){
    alpha  <-  c1 * c2
    beta <- b2 * c1 - a1 * c2
    gamma <- -(a3 * b1 + a1 * b2)
    k1 <- (-beta + sqrt(beta^2 - 4 * alpha * gamma)) / (2 * alpha)
    k2 <- (-beta - sqrt(beta^2 - 4 * alpha * gamma)) / (2 * alpha)
    return(list(k1 = k1, k2 = k2))
}

#plot time series from numerical solution with and without cleanup
#Arguments:
#filename: name of pdf to which figure will be written
#nocleanup and cleanup: output from ode without and with cleanup: first column in each is time, second is neuston, third is plastic
#Value: plots of output against time
plottimeseries <- function(filename, nocleanup, cleanup){
    pdf(file = filename, width = 7, height = 7)
    par(mfrow = c(2, 1))
    par(mar = c(5, 5, 1, 2))
    mycolors <- brewer.pal(3, 'Dark2')
    ylp <- max(rbind(nocleanup[, 3], cleanup[, 3]))
    xlp <- max(rbind(nocleanup[, 2], cleanup[, 2]))
    plot(nocleanup[, 1], nocleanup[, 3], type = "l", xlab = "", ylab = "plastic", col = mycolors[2], lwd = 2, cex.lab = 1.5, ylim = c(0, ylp))
    lines(cleanup[, 1], cleanup[, 3], lwd = 2, col = mycolors[3])
    legend("bottomright", legend = c("no cleanup", "cleanup"), lwd = 2, bty = "n", col = mycolors[2:3], cex = 1.5)
    plot(nocleanup[, 1], nocleanup[, 2], type = "l", xlab = "time", ylab = "neuston", col = mycolors[2], lwd = 2, cex.lab = 1.5, ylim = c(0, xlp))
    lines(cleanup[, 1], cleanup[, 2], lwd = 2, col = mycolors[3])
    dev.off()
}

#plot equilibrium nondimensionalized neuston against equilibrium nondimensionalized plastic for a range of cleanup effort, in case where plastic effect on neuston assumed zero: check formula for this against general approach
#Arguments:
#fname is name of file to plot to as pdf
#a1 is proportional population growth rate of neuston when rare
#b1 is plastic input rate
#b2 is plastic loss rate
#c1 is cleanup efficiency of neuston
#c2 is cleanup efficiency of plastic
#numerical: check by numerical solution (default FALSE)?
#Value: plot of xstar against ystar: line is from full formula, black dots are from simplified formula for special case with no plastic effect on neuston 
plotxstarystarnoa3 <- function(fname, a1, b1, b2, c1, c2, numerical = FALSE){
    kset <- seq(from = 0, to = 1, length.out = 1001)
    xstar <- numeric(length(kset))
    ystar <- numeric(length(kset))
    xstarsimple <- xstar
    for(i in 1:length(kset)){
        k <- kset[i]
        nondimparms <- getdimensionlessparameters(a1 = a1, a3 = 0, b1 = b1, b2 = b2, c1 = c1, c2 = c2, k = k)
        ystar[i] <- 1 / nondimparms[1]
        xstar[i] <- max(0, (-nondimparms[2] - nondimparms[4] * ystar[i]) / nondimparms[3])
        xstarsimple[i] <- max(0, 1 - (1 / ystar[i] - 1) * b2 / a1 * c1 / c2)
    }
    pdf(file = fname, width = 7, height = 7)
    par(mfrow = c(1, 1))
    par(mar = c(5, 5, 2, 2))
    mycolors <- brewer.pal(3, 'Dark2')
    plot(ystar, xstar, type = "l", xlab = expression(italic(y)^"*"), ylab = expression(italic(x)^"*"), cex.lab = 1.5, lwd = 2, col = mycolors[3], xlim = c(0, 1), ylim = c(0, 1))
    points(c(1, 1), pch = 16, col = mycolors[1])
    points(ystar, xstarsimple)
    text(c(1, 1), "no cleanup", adj = c(1, 1.2))
    if(numerical == TRUE){
        for(i in 1:length(kset)){
            k <- kset[i]
            a2 <- -1 #any value is OK here: does not affect outcome
            parameters <- c(a1 = a1, a2 = a2, a3 = 0, c1 = c1, k = k, c2 = c2, b1 = b1, b2 = b2)
            state <- c(x = 0.01, y = 0.1)
            times <- c(0, 1e3)
            nsol <- ode(y = state, times = times, func = plasticneustonlogistic, parms = parameters)
            pnd <- getdimensionlessstate(x = nsol[, 2], y = nsol[, 3], a1 = a1, a2 = a2, a3 = 0, b1 = b1, b2 = b2)
            points(pnd[length(times), 2], pnd[length(times), 1], col = "red")
        }
    }
    minfraction <- getminfraction(a3 = 0, b1 = b1, b2 = b2, c1 = c1, c2 = c2)
    abline(v = minfraction, lty = "dashed")
    abline(h = 1, lty = "dashed")
    points(minfraction, 1, pch = 16, col = mycolors[3])
    text(minfraction, 1, "no net effect", adj = c(-0.2, 1.2))


    kextinct <- getkextinct(a1 = a1, a3 = 0, b1 = b1, b2 = b2, c1 = c1, c2 = c2) #where does extinction happen?
    if(kextinct$k1 > 0){
        ystar0 <- b2 / (b2 + c2 * kextinct$k1)
        y0 <- b1 / (b2 + c2 * kextinct$k1)
        xstar0 <-  (c1 * kextinct$k1 - a1 - 0 * y0) / (-a1 - 0 * b1 / b2)
        points(ystar0, xstar0, col = mycolors[2], pch = 16)
        text(ystar0, xstar0, "extinction", pos = 4)
    }
    if(kextinct$k2 > 0){
        ystar0 <- b2 / (b2 + c2 * kextinct$k2)
        y0 <- b1 / (b2 + c2 * kextinct$k2)
        xstar0 <-  (c1 * kextinct$k2 - a1 - 0 * y0) / (-a1 - 0 * b1 / b2)
        points(ystar0, xstar0, col = mycolors[1], pch = 16)
        text(ystar0, xstar0, "extinction", pos = 4)
    }

    points(b2 * c1 / (a1 * c2 + b2 * c1), 0, col = "red", pch = 8) #simple formula for extinction point when no plastic effect on neuston
    
    dev.off()
}

#approximate loss rate from Koelmans model (data digitized from their figure 4) by a first-order linear differential eq with constant loss rate)
#Arguments: fname is the name of a file containing data digitized from figure 4, macroplastic after emissions cease, variables year and macroplasticmilliontonnes
#figname is name of pdf figure to which we will write the Koelmans data and a line representing fitted model
fitKoelmans <- function(fname, figname){
    mycolors  <- brewer.pal(3, "Dark2")
    koelmansdata <- read.table(file = fname, header = TRUE, sep = "\t")
    koelmansdata$logplastic <- log(koelmansdata$macroplasticmilliontonnes)
    koelmansmodel <- lm(logplastic ~ year, data = koelmansdata)
    print("Year coefficient is estimate of b2 from Koelmans data:")
    print(summary(koelmansmodel))
    pdf(file = figname, width = 7, height = 7)
    plot(koelmansdata$year, koelmansdata$logplastic, xlab = "year", ylab = "log(macroplastic/million tonnes)", pch = 16, col = adjustcolor("black", alpha = 0.4), xaxp = c(2016, 2020, 4))
    abline(koelmansmodel, lwd = 2, col = mycolors[2])
    #legend("topright", bty = "n", pch = c(16, NA), lty = c("blank", "solid"), lwd = 2, legend = c("Koelmans model", "linear first-order"), col = c(adjustcolor("black", alpha = 0.4), mycolors[2])) #probably don't need the legend
    newplotdata <- data.frame(year  = seq(from = min(koelmansdata$year), to = max(koelmansdata$year), length.out = 100), logplastic = NA)
    cldata  <- predict(koelmansmodel, newdata = newplotdata, interval = "confidence", level = 0.95)
    print(head(cldata))
    lines(newplotdata$year, cldata[, 2], lwd = 2, col = mycolors[3] , lty = "dotted")
    lines(newplotdata$year, cldata[, 3], lwd = 2, col = mycolors[3] , lty = "dotted")
    dev.off()
}

#get range of values for a1 by regression from Hatton data
#Arguments:
#fname is name of file containing Hatton 19 data
#figname is name of figure: plot of Hatton data: log growth rate per year against log mass in grams
#diamrange is range of diameters in metres
#densityfname: name of file used to do mass density calculation
#Value: print out predicted values of a1 for masses calculated from diameter, with 95% prediction intervals. Plot the allometry to figname as pdf
a1fromHatton <- function(fname, figname, diamrange, densityfname){
    mycolors <- brewer.pal(3, "Dark2")
    hattondata <- read.delim(file = fname, header = TRUE, sep = "\t")
    pdf(file = figname, width = 7, height = 7)
    plot(log(hattondata$Mass_g), log(hattondata$Growth_rate_per_yr), xlab = "log(mass/g)", ylab = "log(growth rate/year)", pch = 16, col = adjustcolor("black", alpha = 0.2))
    massdensityrange <- getmassdensity(fname = densityfname)
    print("range of mass density in kg per m3:")
    print(massdensityrange)
    massrange <- massfromdiameter(diamrange = diamrange, massdensity = massdensityrange)
    print("range of masses in grams:")
    print(range(massrange))
    abline(v = log(massrange), lwd = 2, col = mycolors[1])
    allometry <- lm(log(Growth_rate_per_yr)  ~ log(Mass_g), data = hattondata)
    print(summary(allometry))
    abline(allometry, lwd = 2, col = mycolors[2])
    print("Predicted max growth rate a1 per year (95% prediction interval):")
    massrangedata <- data.frame(Mass_g  = massrange, Growth_rate_per_year = NA)
    print(cbind(massrange, exp(predict(allometry, newdata = massrangedata, interval = "prediction", level = 0.95))))
    newplotdata <- data.frame(Mass_g  = seq(from = min(hattondata$Mass_g), to = max(hattondata$Mass_g), length.out = 100), Growth_rate_per_year = NA)
    cldata  <- predict(allometry, newdata = newplotdata, interval = "confidence", level = 0.95)
    lines(log(newplotdata$Mass_g), cldata[, 2], lwd = 2, col = mycolors[3] , lty = "dotted")
    lines(log(newplotdata$Mass_g), cldata[, 3], lwd = 2, col = mycolors[3] , lty = "dotted")
    prdata  <- predict(allometry, newdata = newplotdata, interval = "prediction", level = 0.95)
    lines(log(newplotdata$Mass_g), prdata[, 2], lwd = 2, col = mycolors[3] , lty = "dashed")
    lines(log(newplotdata$Mass_g), prdata[, 3], lwd = 2, col = mycolors[3] , lty = "dashed")
    massrangepoints <- predict(allometry, newdata = massrangedata, interval = "prediction", level = 0.95)
    points(log(massrange[c(1, 2)]), c(massrangepoints[1, 3], massrangepoints[2, 2]), pch = 16, col = mycolors[1], cex = 2)
    points(log(massrange[c(3, 4)]), c(massrangepoints[3, 3], massrangepoints[4, 2]), pch = 1, col = mycolors[1], cex = 2)
    dev.off()
}

#get mass from diameter for Hatton allometry analysis
#Arguments:
#diamrange: vector of diameters of organisms in metres
#massdensity: vector of wet mass density in kg per m3 for neuston
#Value:
#massrange: vector of masses in grams (all the combinations of a diameter and a mass density in input vector, in ascending order)
massfromdiameter <- function(diamrange, massdensity){
    volrange <- 4 / 3 * pi * (diamrange / 2) ^3 #assume spherical: volumes in metres cubed
    massrange <- as.numeric(outer(volrange, massdensity)) * 1e3
    massrange <- massrange[order(massrange)]
    return(massrange)
}

#estimate mass density for neuston from Betti et al 2019 EZJ 86:343-353 Velella count and mass in strandings
#Arguments: fname is name of tab-separated text file containing variables coloniesperm2, lengthmm, wetwtgperm2
#Value: range of wet mass density (kg per m3) for Velella from Betti data
getmassdensity <- function(fname){
    betti <- read.table(file = fname, header = TRUE, sep = "\t")
    betti$volm3 <- 4 / 3 * pi * (betti$lengthmm / (1000 * 2)) ^ 3 #assume spherical: volumes in metres cubed
    betti$massdensity <- (betti$wetwtgperm2 / 1000) / (betti$coloniesperm2 * betti$volm3)
    return(range(betti$massdensity))
        
}

#preliminary summary figure: proportion neuston remaining against proportional reduction in plastic, for low and high values of intrinsic neuston growth rate and cleanup efficiency, and a single value of natural loss rate
#Arguments:
#fname is name of png figure to plot to
#lengthfname: name of tab-separated text file containing variables coloniesperm2, lengthmm, wetwtgperm2, used to estimate mass for target species
#allometryfname: name of file containing Hatton 2019 data for allometry calculation
#b2 is plastic loss rate (single value)
#c1low, c1high, c1mid: low, high, mid values of cleanup efficiency of neuston relative to plastic
#windows (logical, default FALSE: if true, load Arial font required by NERC, but may only work on Windows)
#Value: png figure with proportion neuston remaining against proportional reduction in plastic, for c1mid (highlighted) and c1low, c1high (lighter shade): for each, intervals reflecting uncertainty in a1
trackrecordfigure <- function(fname, lengthfname, allometryfname, b2, c1low, c1high, c1mid, windows = FALSE){
    betti <- read.table(file = lengthfname, header = TRUE, sep = "\t")
    lengthmm <- mean(betti$lengthmm) #mean length for stranded Velella
    hattondata <- read.delim(file = allometryfname, header = TRUE, sep = "\t")
    massdensityrange <- getmassdensity(fname = lengthfname)
    massrange <- massfromdiameter(diamrange = lengthmm / 1000, massdensity = massdensityrange)

    print(massdensityrange)
    print(massrange)
    allometry <- lm(log(Growth_rate_per_yr)  ~ log(Mass_g), data = hattondata)
    massrangedata <- data.frame(Mass_g  = massrange, Growth_rate_per_year = NA)
    a1predict <- exp(predict(allometry, newdata = massrangedata, interval = "prediction", level = 0.95))
    print("Predicted intrinsic growth rate for Velella:")
    print(cbind(massrange, a1predict))
    a1low <- a1predict[2, 2]
    a1high <- a1predict[1, 3]
    if(windows){
        loadfonts(device = "win") #need Arial font for NERC applications: may not work except on Windows
        png(fname, family = "Arial")
    } else {
        warning("Not using Arial font: may not be suitable for NERC")
        png(fname) #when we aren't on Windows and don't need Arial
    }
    par(mar = c(5, 5, 2, 2))
    pstar <- seq(from = 0, to = 1, length.out = 100)
    c1seq <- c(c1low, c1high, c1mid)
    mycolors <- c("grey", "grey", "black")
    plot(c(0, 1), c(0, 1), type = "n", xlab = "proportional reduction in plastic", ylab = "proportion neuston remaining", cex.lab = 2, cex.axis = 1.5)
    for(i in 1:3){
        nstarlow <- 1 - (1 / pstar - 1) * b2 / a1low * c1seq[i]
        nstarhigh <- 1 - (1 / pstar - 1) * b2 / a1high * c1seq[i]
        nstarlow[nstarlow < 0]  <- 0
        nstarhigh[nstarhigh < 0]  <- 0
        polygon(c(1 - pstar, rev(1 - pstar)), c(nstarlow, rev(nstarhigh)), border = NA, col = mycolors[i])
    }
    dev.off()
}

#get ranges of a1 for large and small neuston
#Arguments:
#allometryfname: name of file containing Hatton 2019 data for allometry calculation
#lengthfname: name of tab-separated text file containing variables coloniesperm2, lengthmm, wetwtgperm2, used to estimate mass for target species
#length: vector of two elements: lengths in mm for small and large neuston species
#Value:
#list of two vectors, a1small and a1large, containing range of a1 for small and large neuston respectively
geta1 <- function(allometryfname, lengthfname, length){
    hattondata <- read.delim(file = allometryfname, header = TRUE, sep = "\t")
    massdensityrange <- getmassdensity(fname = lengthfname)
    massrange <- massfromdiameter(diamrange = length / 1000, massdensity = massdensityrange)
    allometry <- lm(log(Growth_rate_per_yr)  ~ log(Mass_g), data = hattondata)
    massrangedata <- data.frame(Mass_g  = massrange, Growth_rate_per_year = NA)
    a1predict <- exp(predict(allometry, newdata = massrangedata, interval = "prediction", level = 0.95))
    a1lowsmall <- a1predict[2, 2]
    a1highsmall <- a1predict[1, 3]
    a1lowlarge <- a1predict[4, 2]
    a1highlarge <- a1predict[3, 3]
    a1small <- c(a1lowsmall, a1highsmall)
    a1large <- c(a1lowlarge, a1highlarge)
    return(list(a1small = a1small, a1large = a1large))
}

#figures for paper
#Arguments:
#fnamesmall: name of figure for effects on a small neuston species
#fnamelarge: name of figure for effects on a large neuston species
#fnamecombined: name of figure for effects in best and worst cases
#length: vector of two elements: lengths in mm for small and large neuston species
#lengthfname: name of tab-separated text file containing variables coloniesperm2, lengthmm, wetwtgperm2, used to estimate mass for target species
#allometryfname: name of file containing Hatton 2019 data for allometry calculation
#b2 is plastic loss rate (vector of low and high values
#c1c2: vector of two elements: low, high values of cleanup efficiency of neuston relative to plastic
#Value: pdf figures as named above
paperfigures <- function(fnamesmall, fnamelarge, fnamecombined, length, lengthfname, allometryfname, b2, c1c2){
    hattondata <- read.delim(file = allometryfname, header = TRUE, sep = "\t")
    massdensityrange <- getmassdensity(fname = lengthfname)
    massrange <- massfromdiameter(diamrange = length / 1000, massdensity = massdensityrange)
    allometry <- lm(log(Growth_rate_per_yr)  ~ log(Mass_g), data = hattondata)
    massrangedata <- data.frame(Mass_g  = massrange, Growth_rate_per_year = NA)
    a1predict <- exp(predict(allometry, newdata = massrangedata, interval = "prediction", level = 0.95))
    a1lowsmall <- a1predict[2, 2]
    a1highsmall <- a1predict[1, 3]
    a1lowlarge <- a1predict[4, 2]
    a1highlarge <- a1predict[3, 3]
    pdf(file = fnamesmall, width = 7, height = 7)
    par(mar = c(5, 5, 2, 2))
    pstar <- seq(from = 0, to = 1, length.out = 100)
    mycolors <- brewer.pal(3, 'Dark2')
    mylinestyles <- c("solid", "dashed")
    mypch <- c(NA, 16)
    plot(c(0, 1), c(0, 1), type = "n", xlab = "proportional reduction in plastic", ylab = "proportion neuston remaining", cex.lab = 2, cex.axis = 1.5)
    a1 <- c(a1lowsmall, a1highsmall)
    whichpoints <- seq(from = 1, to = length(pstar), length.out = 20)
    for(i in 1:2){#values of c1 / c2
        for(j in 1:2){#values of b2
            for(k in 1:2){#values of a1
                nstar <- 1 - (1 / pstar - 1) * b2[j] / a1[k] * c1c2[i]
                nstar[nstar < 0]  <- 0
                lines(1 - pstar, nstar, col = mycolors[i], lwd = 2, lty = mylinestyles[j])
                points(1 - pstar[whichpoints], nstar[whichpoints], col = mycolors[i], pch = mypch[k])
            }
        }
    }
    legend(x = 0.1, y = 0.6, col = rep(mycolors[1:2], 4), lty = c("solid", "solid", "dashed", "dashed", "solid", "solid", "dashed", "dashed"), pch = c(NA, NA, NA, NA, 16, 16, 16, 16), lwd = c(2, 2, 2, 2, 2, 2), legend = c(expression(paste(italic(a)[1], ~low, ",", ~italic(b)[2], ~low, ",", ~italic(c)[1]/italic(c)[2], ~low)), expression(paste(italic(a)[1], ~low, ",", ~italic(b)[2], ~low, ",", ~italic(c)[1]/italic(c)[2], ~high)), expression(paste(italic(a)[1], ~low, ",", ~italic(b)[2], ~high, ",", ~italic(c)[1]/italic(c)[2], ~low)), expression(paste(italic(a)[1], ~low, ",", ~italic(b)[2], ~high, ",", ~italic(c)[1]/italic(c)[2], ~high)), expression(paste(italic(a)[1], ~high, ",", ~italic(b)[2], ~low, ",", ~italic(c)[1]/italic(c)[2], ~low)), expression(paste(italic(a)[1], ~high, ",", ~italic(b)[2], ~low, ",", ~italic(c)[1]/italic(c)[2], ~high)), expression(paste(italic(a)[1], ~high, ",", ~italic(b)[2], ~high, ",", ~italic(c)[1]/italic(c)[2], ~low)), expression(paste(italic(a)[1], ~high, ",", ~italic(b)[2], ~high, ",", ~italic(c)[1]/italic(c)[2], ~high))), bty = "n")
    dev.off()
    
    pdf(file = fnamelarge, width = 7, height = 7)
    par(mar = c(5, 5, 2, 2))
    pstar <- seq(from = 0, to = 1, length.out = 100)
    mycolors <- brewer.pal(3, 'Dark2')
    mylinestyles <- c("solid", "dashed")
    mypch <- c(NA, 16)
    plot(c(0, 1), c(0, 1), type = "n", xlab = "proportional reduction in plastic", ylab = "proportion neuston remaining", cex.lab = 2, cex.axis = 1.5)
    a1 <- c(a1lowlarge, a1highlarge)
    whichpoints <- seq(from = 1, to = length(pstar), length.out = 20)
    for(i in 1:2){
        for(j in 1:2){
            for(k in 1:2){
                nstar <- 1 - (1 / pstar - 1) * b2[j] / a1[k] * c1c2[i]
                nstar[nstar < 0]  <- 0
                lines(1 - pstar, nstar, col = mycolors[i], lwd = 2, lty = mylinestyles[j])
                points(1 - pstar[whichpoints], nstar[whichpoints], col = mycolors[i], pch = mypch[k])
            }
        }
    }
    legend(x = 0.4, y = 0.6, col = rep(mycolors[1:2], 4), lty = c("solid", "solid", "dashed", "dashed", "solid", "solid", "dashed", "dashed"), pch = c(NA, NA, NA, NA, 16, 16, 16, 16), lwd = c(2, 2, 2, 2, 2, 2), legend = c(expression(paste(italic(a)[1], ~low, ",", ~italic(b)[2], ~low, ",", ~italic(c)[1]/italic(c)[2], ~low)), expression(paste(italic(a)[1], ~low, ",", ~italic(b)[2], ~low, ",", ~italic(c)[1]/italic(c)[2], ~high)), expression(paste(italic(a)[1], ~low, ",", ~italic(b)[2], ~high, ",", ~italic(c)[1]/italic(c)[2], ~low)), expression(paste(italic(a)[1], ~low, ",", ~italic(b)[2], ~high, ",", ~italic(c)[1]/italic(c)[2], ~high)), expression(paste(italic(a)[1], ~high, ",", ~italic(b)[2], ~low, ",", ~italic(c)[1]/italic(c)[2], ~low)), expression(paste(italic(a)[1], ~high, ",", ~italic(b)[2], ~low, ",", ~italic(c)[1]/italic(c)[2], ~high)), expression(paste(italic(a)[1], ~high, ",", ~italic(b)[2], ~high, ",", ~italic(c)[1]/italic(c)[2], ~low)), expression(paste(italic(a)[1], ~high, ",", ~italic(b)[2], ~high, ",", ~italic(c)[1]/italic(c)[2], ~high))), bty = "n")
    dev.off()

    pdf(file = fnamecombined, width = 7, height = 7)
    par(mar = c(5, 5, 2, 2))
    pstar <- seq(from = 0, to = 1, length.out = 100)
    mycolors <- brewer.pal(3, 'Dark2')
    mylinestyles <- c("solid", "dashed")
    mypch <- c(NA, 16)
    plot(c(0, 1), c(0, 1), type = "n", xlab = "proportional reduction in plastic", ylab = "proportion neuston remaining", cex.lab = 2, cex.axis = 1.5)
    whichpoints <- seq(from = 1, to = length(pstar), length.out = 20)
    nstarworst <- 1 - (1 / pstar - 1) * b2[2] / a1lowlarge * c1c2[2]
    nstarworst[nstarworst < 0]  <- 0
    lines(1 - pstar, nstarworst, col = mycolors[2], lwd = 2, lty = mylinestyles[2])
    nstarbest <- 1 - (1 / pstar - 1) * b2[1] / a1highsmall * c1c2[1]
    nstarbest[nstarbest < 0]  <- 0
   lines(1 - pstar, nstarbest, col = mycolors[1], lwd = 2, lty = mylinestyles[1])
   points(1 - pstar[whichpoints], nstarbest[whichpoints], col = mycolors[1], pch = mypch[2])
    legend(x = 0.1, y = 0.6, col = mycolors[1:2], lty = c("solid", "dashed"), pch = c(16, NA), lwd = c(2, 2), bty = "n", legend = c(expression(paste(small~neuston, ",",~italic(a)[1], ~high, ",", ~italic(b)[2], ~low, ",", ~italic(c)[1]/italic(c)[2], ~low)), expression(paste(large~neuston, ",",~italic(a)[1], ~low, ",", ~italic(b)[2], ~high, ",", ~italic(c)[1]/italic(c)[2], ~high))))
    dev.off()
}

#plot scaled neuston against time for a range of values of a1 and b2, under the assumption that c2k = b2 (halve plastic at equilibrium) and c1 / c2 = 1 (equal efficiency of removal of neuston and plastic). Assumes initially at equilibrium with no cleanup.
#Arguments:
#fname: name of pdf figure to produce
#a1: proportional population growth rate at low density, vector of two values: low value for large neuston, high value for small neuston
#b2: natural loss rate of macroplastic, vector of two values (low and high)
#Value: in fname, scaled neuston against time for each combination of a1 and b2
timescalefigure  <- function(fname, a1, b2, tmax){
    t <- seq(from = 0, to = tmax, length.out = 100)
    pdf(file = fname, width = 7, height = 7)
    par(mar = c(5, 5, 2, 2))
    plot(c(0, tmax), c(0, 1), type = "n", xlab = "time/years", ylab = "scaled neuston concentration", ylim = c(0, 1), cex.lab = 1, cex.axis = 1)
    c1k <- b2 #assume we want to halve plastic at equilibrium, and c1 / c2 = 1
    mylinestyles <- c("solid", "dashed")
    mycolors <- brewer.pal(3, "Dark2")
    mypch <- c(NA, 16)
    whichpoints <- seq(from = 1, to = length(t), length.out = 20)
    for(i in 1:2){
        for(j in 1:2){
            alpha1 <- a1[i] - c1k[j]
            nstar <- (alpha1 / a1[i]) / (1 + (alpha1 / a1[i] - 1) * exp(-alpha1 * t))
            lines(t, nstar, lwd = 2, lty = mylinestyles[j])
            points(t[whichpoints], nstar[whichpoints], pch = mypch[i]) 
        }
    }
    legend(x = 0.4 * tmax, y = 0.4, lty = c("solid", "dashed", "solid", "dashed"), pch = c(mypch[1], mypch[1], mypch[2], mypch[2]), legend = c(expression(paste(italic(a)[1], ~"low for large neuston,", ~italic(c[1]*k), ~ low)), expression(paste(italic(a)[1], ~"low for large neuston,", ~italic(c[1]*k), ~ high)), expression(paste(italic(a)[1], ~"high for small neuston,", ~italic(c[1]*k), ~ low)), expression(paste(italic(a)[1], ~"high for small neuston,", ~italic(c[1]*k), ~ high))), bty = "n")
    dev.off()
}

#Plot effects of varying parameters on proportion neuston remaining for given proportional reduction in plastic
#Arguments:
#a1small, a1large: vectors of min and max value of a1 for small and large neuston respectively
#b2: vector of min and max value of b2
#c1c2: vector of min and max value of c1/c2
#nlines: number of different values of varying parameter to plot (default 10)
#fname: name of pdf file to write
#Value: pdf figure with six panels. Small neuston in left column, large neuston in right. For each panel: shade envelope of possible effects over full range of parameters, and plot nlines lines with equally-spaced values of the varying parameter, while holding others at their midpoints. Rows: vary a1, b2, c1/c2 from top to bottom.
plotparametereffects <- function(a1small, a1large, b2, c1c2, nlines = 10, fname){
    a1midsmall <- exp(mean(log(a1small)))
    a1midlarge <- exp(mean(log(a1large)))
    print("geometric midpoint for a1 small:")
    print(a1midsmall)
    print("geometric midpoint for a2 large:")
    print(a1midlarge)

    a1smallvalues <- exp(seq(from = log(a1small[1]), to = log(a1small[2]), length.out = nlines))
    a1largevalues <- exp(seq(from = log(a1large[1]), to = log(a1large[2]), length.out = nlines))
    b2mid <- exp(mean(log(b2)))
    print("geometric midpoint for b2:")
    print(b2mid)

    b2values <- exp(seq(from = log(b2[1]), to = log(b2[2]), length.out = nlines))
    c1c2mid <- exp(mean(log(c1c2)))
    print("geometric midpoint for c1c2:")
    print(c1c2mid)
    c1c2values <- exp(seq(from = log(c1c2[1]), to = log(c1c2[2]), length.out = nlines))

    pstar <- seq(from = 0, to = 1, length.out = 1e3)
    nstarlowsmall <- 1 - (1 / pstar - 1) * b2[1] / a1small[2] * c1c2[1]
    nstarlowsmall[nstarlowsmall < 0]  <- 0
    nstarhighsmall <- 1 - (1 / pstar - 1) * b2[2] / a1small[1] * c1c2[2]
    nstarhighsmall[nstarhighsmall < 0]  <- 0
    nstarlowlarge <- 1 - (1 / pstar - 1) * b2[1] / a1large[2] * c1c2[1]
    nstarlowlarge[nstarlowlarge < 0]  <- 0
    nstarhighlarge <- 1 - (1 / pstar - 1) * b2[2] / a1large[1] * c1c2[2]
    nstarhighlarge[nstarhighlarge < 0]  <- 0
    alphavalues <- seq(from = 0.2, to = 1, length.out = nlines)
    mycolors <- brewer.pal(3, "Dark2")
    pdf(file = fname, width = 7, height = 10.5)
    par(mfrow = c(3, 2))
    par(mar = c(4, 5, 2, 2))
    drawoneeffectpanel(pstar = pstar, nstarlow = nstarlowsmall, nstarhigh = nstarhighsmall, linecolor = mycolors[1], label = expression(paste("A: small neuston, varying ", italic(a[1]))), legend = round(a1smallvalues, 2), legendtitle = expression(italic(a)[1]), a1vals = a1smallvalues, b2vals = rep(b2mid, nlines), c1c2vals = rep(c1c2mid, nlines)) #small neuston, vary a1, b2 and c1/c2 at midpoints
    drawoneeffectpanel(pstar = pstar, nstarlow = nstarlowlarge, nstarhigh = nstarhighlarge, linecolor = mycolors[1], label = expression(paste("B: large neuston, varying ", italic(a[1]))), legend = round(a1largevalues, 2), legendtitle = expression(italic(a)[1]), a1vals = a1largevalues, b2vals = rep(b2mid, nlines), c1c2vals = rep(c1c2mid, nlines)) #large neuston, vary a1, b2 and c1/c2 at midpoints
    drawoneeffectpanel(pstar = pstar, nstarlow = nstarlowsmall, nstarhigh = nstarhighsmall, linecolor = mycolors[2], label = expression(paste("C: small neuston, varying ", italic(b[2]))), legend = round(b2values, 2), legendtitle = expression(italic(b)[2]), a1vals = rep(a1midsmall, nlines), b2vals = b2values, c1c2vals = rep(c1c2mid, nlines)) #small neuston, vary b2, a1 and c1/c2 at midpoints
    drawoneeffectpanel(pstar = pstar, nstarlow = nstarlowlarge, nstarhigh = nstarhighlarge, linecolor = mycolors[2], label = expression(paste("D: large neuston, varying ", italic(b[2]))), legend = round(b2values, 2), legendtitle = expression(italic(b)[2]), a1vals = rep(a1midlarge, nlines), b2vals = b2values, c1c2vals = rep(c1c2mid, nlines)) #large neuston, vary b2, a1 and c1/c2 at midpoints
    drawoneeffectpanel(pstar = pstar, nstarlow = nstarlowsmall, nstarhigh = nstarhighsmall, linecolor = mycolors[3], label = expression(paste("E: small neuston, varying ", italic(c[1]/c[2]))), legend = round(c1c2values, 2), legendtitle = expression(italic(c)[1] / italic(c)[2]), a1vals = rep(a1midsmall, nlines), b2vals = rep(b2mid, nlines), c1c2vals = c1c2values) #small neuston, vary c1/c2, a1 and b2 at midpoints
    drawoneeffectpanel(pstar = pstar, nstarlow = nstarlowlarge, nstarhigh = nstarhighlarge, linecolor = mycolors[3], label = expression(paste("F: large neuston, varying ", italic(c[1]/c[2]))), legend = round(c1c2values, 2), legendtitle = expression(italic(c)[1] / italic(c)[2]), a1vals = rep(a1midlarge, nlines), b2vals = rep(b2mid, nlines), c1c2vals = c1c2values) #large neuston, vary c1/c2, a1 and b2 at midpoints
    dev.off()
}

#plot one panel of parameter effects
#Arguments:
#pstar: vector of proportion plastic remaining
#nstarlow, nstarhigh: vectors of proportion neuston remaining (low and high boundaries of envelope respectively)
#linecolor: colour for lines showing effect of varying parameters (single colour: lines will be distinguished by transparency)
#label: panel label
#legend: values to put as legend labels
#legendtitle: title for legend
#a1vals: vector of values for a1
#b2vals: vector of values for b2
#c1c2vals: vector of values for c1/c2
#note: these three vectors should be same length, but suggest all but one constant
#Value: plot proportion neuston remaining against proportional reduction in plastic. Shade envelope of possible values. Lines indicating effects of varying parameters
drawoneeffectpanel <- function(pstar, nstarlow, nstarhigh, linecolor, label, legend, legendtitle, a1vals, b2vals, c1c2vals){
    colfun <- function(x, color){adjustcolor(color, x)}
    plot(c(0, 1), c(0, 1), type = "n", xlab = "proportional reduction in plastic", ylab = "proportion neuston remaining", cex.lab = 1, cex.axis = 1, asp = 1)
    polygon(c(1 - pstar, rev(1 - pstar)), c(nstarlow, rev(nstarhigh)), col = "lightgray", border = NA)
    nlines <- length(a1vals)
    alphavalues <- seq(from = 0.2, to = 1, length.out = nlines)
    linecolors <- sapply(alphavalues, FUN = colfun, color = linecolor)
    Pi <- b2vals / a1vals * c1c2vals
    for(i in 1:nlines){
        nstarline <- 1 - (1 / pstar - 1) * b2vals[i] / a1vals[i] * c1c2vals[i]
        nstarline[nstarline < 0] <- 0
        lines(1 - pstar, nstarline, col = linecolors[i])
    }
    legend(x = 0.2, y = 0.7, pch = NA, lty = "solid", col = linecolors, legend = legend, bty = "n", title = legendtitle)
    axl <- par("usr")
    text(axl[1] + 0.1 * (axl[2] - axl[1]), axl[3] + 0.1 * (axl[4] - axl[3]), label, pos = 4)
}

#Plot effects of varying parameters on proportion neuston remaining for given proportional reduction in plastic
#Arguments:
#a1small, a1large: vectors of min and max value of a1 for small and large neuston respectively
#b2: vector of min and max value of b2
#c1c2: vector of values of c1/c2 (default (0.1, 1, 10))
#Piset: vector of three values of Pi = b2/a1 * c1/c2 (default (1e-3, 1, 7.5))
#fname: name of pdf file to write
#Value: pdf figure with four panels. Small neuston in top row, large neuston in bottom row. For left panels: shade envelope of possible effects over full range of parameters, and plot lines corresponding to the three values of Pi. 
#For right panels: plot values of a1 and b2 required to achieve each value of Pi, for each value of c1/c2 (match to values of Pi by line styles, distinguish values of c1/c2 by colour)
parameterratiofigure <- function(a1small, a1large, b2, c1c2 = c(0.1, 1, 10), Piset = c(1e-3, 1, 7.5), fname){
    pstar <- seq(from = 0, to = 1, length.out = 1e3)
    nstarlowsmall <- 1 - (1 / pstar - 1) * b2[1] / a1small[2] * min(c1c2)
    nstarlowsmall[nstarlowsmall < 0]  <- 0
    nstarhighsmall <- 1 - (1 / pstar - 1) * b2[2] / a1small[1] * max(c1c2)
    nstarhighsmall[nstarhighsmall < 0]  <- 0
    nstarlowlarge <- 1 - (1 / pstar - 1) * b2[1] / a1large[2] * min(c1c2)
    nstarlowlarge[nstarlowlarge < 0]  <- 0
    nstarhighlarge <- 1 - (1 / pstar - 1) * b2[2] / a1large[1] * max(c1c2)
    nstarhighlarge[nstarhighlarge < 0]  <- 0
#    alphavalues <- seq(from = 0.2, to = 1, length.out = length(Piset))
    alphavalues <- rep(1, length(Piset)) #distinguishing by line style probably works better than by transparency
    mycolors <- c(brewer.pal(length(c1c2), "Reds"), "black")
    colfun <- function(x, color){adjustcolor(color, x)}
    linecolors <- array(dim = c(length(Piset), length(c1c2) + 1))
    for(j in 1:(length(c1c2) + 1)){
        linecolors[, j] <- sapply(alphavalues, FUN = colfun, color = mycolors[j])
    }
    linestyles <- c("dotted", "dashed", "solid")

    pdf(file = fname, width = 7, height = 7)
    par(mfrow = c(2, 2))
    par(mar = c(4, 5, 3, 2))

    plot(c(0, 1), c(0, 1), type = "n", xlab = "proportional reduction in plastic", ylab = "proportion neuston remaining", cex.lab = 1, cex.axis = 1, asp = 1, main = c("a: small neuston"))
    polygon(c(1 - pstar, rev(1 - pstar)), c(nstarlowsmall, rev(nstarhighsmall)), col = "lightgray", border = NA)

    for(i in 1:length(Piset)){
        nstarset <- 1 - (1 / pstar - 1) * Piset[i]
        nstarset[nstarset < 0] <- 0
        lines(1 - pstar, nstarset, col = linecolors[i, length(c1c2) + 1], lwd = 2, lty = linestyles[i])
    }
    legend(x = 0.6, y = 0.6, pch = NA, col = linecolors[, length(c1c2) + 1], lwd = 2, legend = Piset, bty = "n", title = expression(Pi), lty = linestyles)
    
    plot(range(c(a1small, a1large)), b2, type = "n", xlab = expression(italic(a[1])), ylab = expression(italic(b[2])), log = "xy", main = "b: small neuston")
    for(i in 1:length(Piset)){
        for(j in 1:length(c1c2)){
            a1set <- seq(from = a1small[1], to = a1small[2], length.out = 100)
            b2set <- Piset[i] / c1c2[j] * a1set
            lines(a1set, b2set, col = linecolors[i, j], lwd = 2, lty = linestyles[i])
        }
    }
    legend("right", pch = NA, col = mycolors, lwd = 2, legend = c1c2, bty = "n", title = expression(italic(c[1]/c[2])))

    plot(c(0, 1), c(0, 1), type = "n", xlab = "proportional reduction in plastic", ylab = "proportion neuston remaining", cex.lab = 1, cex.axis = 1, asp = 1, main = "c: large neuston")
    polygon(c(1 - pstar, rev(1 - pstar)), c(nstarlowlarge, rev(nstarhighlarge)), col = "lightgray", border = NA)
    for(i in 1:length(Piset)){
        nstarset <- 1 - (1 / pstar - 1) * Piset[i]
        nstarset[nstarset < 0] <- 0
        lines(1 - pstar, nstarset, col = linecolors[i, length(c1c2) + 1], lwd = 2, lty = linestyles[i])
    }
    legend(x = 0.6, y = 0.6, pch = NA, col = linecolors[, length(c1c2) + 1], lwd = 2, legend = Piset, bty = "n", title = expression(Pi), lty = linestyles)

    plot(range(c(a1small, a1large)), b2, type = "n", xlab = expression(italic(a[1])), ylab = expression(italic(b[2])), log = "xy", main = "d: large neuston")
    for(i in 1:length(Piset)){
        for(j in 1:length(c1c2)){
            a1set <- seq(from = a1large[1], to = a1large[2], length.out = 100)
            b2set <- Piset[i] / c1c2[j] * a1set
            lines(a1set, b2set, col = linecolors[i, j], lwd = 2, lty = linestyles[i])
        }
    }
    legend("right", pch = NA, col = mycolors, lwd = 2, legend = c1c2, bty = "n", title = expression(italic(c[1]/c[2])))
    dev.off()
}


fitKoelmans(fname = "koelmansdata.txt", figname = "Koelmansfitted.pdf")

a1fromHatton(fname = "Hatton19data.txt", figname = "Hattonfitted.pdf", diamrange = c(0.01, 0.3), densityfname <- "Bettidata.txt")


paperfigures(fnamesmall = "effects_smalltaxa.pdf", fnamelarge = "effects_largetaxa.pdf", fnamecombined = "effects_combined.pdf", length = c(10, 300), lengthfname = "Bettidata.txt", allometryfname = "Hatton19data.txt", b2 = c(0.03, 1.26), c1c2 = c(0.1, 10)) #b2 full range, c1/c2 full range, a1 range calculated from given lengths and Hatton allometry

timescalefigure(fname = "timescalefigure.pdf", a1 = c(0.08, 63.52), b2 = c(0.03, 1.26), tmax = 10) #scaled neuston against time, if cleanup starts at time zero

a1list <- geta1(allometryfname = "Hatton19data.txt", lengthfname = "Bettidata.txt", length = c(10, 300))
plotparametereffects(a1small = a1list$a1small, a1large = a1list$a1large, b2 = c(0.03, 1.26), c1c2 = c(0.1, 10), nlines = 5, fname = "effects_varyparameters.pdf")
parameterratiofigure(a1small = a1list$a1small, a1large = a1list$a1large, b2 = c(0.03, 1.26), c1c2 = c(0.1, 1, 10), Piset = c(1e-3, 1, 7.5), fname = "parameterratio.pdf")

